==> rc-ui-lib-0.1.41.tgz: package/es/checkbox/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { act } from 'react-dom/test-utils';
import { Checkbox } from '../index';
import mountTest from '../../../tests/shared/mountTest';
import { sleep } from '../../../tests/utils';
describe('Checkbox', function () {
  mountTest(Checkbox);
  mountTest(function () {
    return /*#__PURE__*/React.createElement(Checkbox, {
      checked: true,
      onChange: jest.fn()
    }, "Label");
  });
  it('renders correctly', function () {
    expect( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      onChange: jest.fn()
    }, "Label")).toMatchRenderedSnapshot();
  });
  it('render Custom icon correctly', function () {
    var activeIcon = 'https://img.yzcdn.cn/vant/user-active.png';
    var inactiveIcon = 'https://img.yzcdn.cn/vant/user-inactive.png';
    expect( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      iconRender: function iconRender(_ref) {
        var isActive = _ref.checked;
        return /*#__PURE__*/React.createElement("img", {
          alt: "",
          src: isActive ? activeIcon : inactiveIcon
        });
      }
    }, "\u81EA\u5B9A\u4E49\u56FE\u6807")).toMatchRenderedSnapshot();
  });
  it('should emit change event when checkbox icon is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onChange, wrapper, icon;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
              onChange: onChange
            }, "Label"));
            icon = wrapper.find('.rc-checkbox__icon');
            icon.simulate('click');
            expect(onChange).toBeCalledWith(true);
            _context.next = 7;
            return wrapper.setProps({
              checked: true
            });

          case 7:
            icon.simulate('click');
            expect(onChange).toBeCalledWith(false);

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should emit toggle event when checkbox is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var checkboxRef, toggle, wrapper;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            // const onToggle = jest.fn();
            checkboxRef = /*#__PURE__*/React.createRef();

            toggle = function toggle(checked) {
              checkboxRef.current.toggle(checked);
            };

            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
              ref: checkboxRef
            }, "Label"));
            _context3.next = 5;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
              return _regeneratorRuntime.wrap(function _callee2$(_context2) {
                while (1) {
                  switch (_context2.prev = _context2.next) {
                    case 0:
                      toggle();

                    case 1:
                    case "end":
                      return _context2.stop();
                  }
                }
              }, _callee2);
            })));

          case 5:
            wrapper.update();
            _context3.next = 8;
            return sleep();

          case 8:
            expect(wrapper.childAt(0).props().checked).toEqual(true); // expect(onToggle).toBeCalled();

          case 9:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should not emit "change" event when checkbox icon is disabled and clicked', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      disabled: true,
      onChange: onChange
    }, "Label"));
    wrapper.find('.rc-checkbox__icon').simulate('click');
    expect(onChange).not.toHaveBeenCalled();
  });
  it('should render "rc-checkbox--label-disabled" class when using label-disabled prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      labelDisabled: true,
      onChange: jest.fn()
    }, "Label"));
    expect(wrapper.find('.rc-checkbox--label-disabled')).toBeTruthy();
  });
  it('should emit "change" event when label is clicked', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      onChange: onChange
    }, "Label"));
    var icon = wrapper.find('.rc-checkbox__label');
    icon.simulate('click');
    expect(onChange).toBeCalledWith(false);
  });
  it('should not emit "change" event when label is disabled and clicked', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      labelDisabled: true,
      onChange: onChange
    }, "Label"));
    var icon = wrapper.find('.rc-checkbox__label');
    icon.simulate('click');
    expect(onChange).not.toHaveBeenCalled();
  });
  it('should adjust label position when using label-position prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      labelPosition: "left",
      onChange: jest.fn()
    }, "Label"));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should emit click event when checkbox icon is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var onClick, wrapper, icon;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            onClick = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
              defaultChecked: true,
              labelPosition: "left",
              onClick: onClick
            }, "Label"));
            wrapper.simulate('click');
            expect(onClick).toHaveBeenCalledTimes(1);
            icon = wrapper.find('.rc-checkbox__icon');
            icon.simulate('click');
            expect(onClick).toHaveBeenCalledTimes(2);

          case 7:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
});
describe('Checkbox.Group', function () {
  mountTest(Checkbox.Group);
  it('renders correctly', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['1']
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "0"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "1",
      checked: true
    }, "\u9009\u9879\u4E8C"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "2"
    }, "\u9009\u9879\u4E09")));
    expect(wrapper).toMatchSnapshot();
  });
  it('render value correctly', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['0']
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "0"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "1"
    }, "\u9009\u9879\u4E8C"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "2"
    }, "\u9009\u9879\u4E09")));
    expect(wrapper).toMatchSnapshot();
  });
  it('should change icon size when using icon-size prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['1'],
      iconSize: "10rem"
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "0"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "1",
      iconSize: "5rem",
      checked: true
    }, "\u9009\u9879\u4E8C")));
    var icons = wrapper.find('.rc-checkbox__icon'); // expect(icons).toHaveLength(2);
    // console.log(icons.debug());
    // console.log(icons.at(0).getDOMNode());
    // console.log(icons.at(0).getDOMNode());

    expect(icons.at(0).getDOMNode().style.fontSize).toEqual('10rem');
    expect(icons.at(1).getDOMNode().style.fontSize).toEqual('5rem');
  });
  it('should limit change num when using max prop', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['a', 'b'],
      max: 2,
      onChange: onChange
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "a"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "b"
    }, "\u9009\u9879\u4E8C"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "c"
    }, "\u9009\u9879\u4E09")));
    var icons = wrapper.find('.rc-checkbox__icon');
    icons.at(2).simulate('click');
    expect(onChange).toHaveBeenCalledTimes(0);
    icons.at(0).simulate('click');
    expect(onChange).toHaveBeenCalledTimes(1);
    icons.at(0).simulate('click');
    expect(onChange).toHaveBeenCalledTimes(2);
  });
  it('should change checked color when using checked-color prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['a', 'b'],
      checkedColor: "black"
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "a"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "b",
      checkedColor: "white"
    }, "\u9009\u9879\u4E8C")));
    var icons = wrapper.find('i.van-icon'); // console.log(icons.at(0).getDOMNode().style);
    // console.log(icons.at(1).getDOMNode().style);

    expect(icons).toHaveLength(2);
    expect(icons.at(0).getDOMNode().style.backgroundColor).toEqual('black');
    expect(icons.at(1).getDOMNode().style.backgroundColor).toEqual('white');
  });
  it('should ignore Checkbox if bind-group is false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onChange, groupValue, groupRef, toggleAll, wrapper, items;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            onChange = jest.fn();
            groupValue = [];
            groupRef = /*#__PURE__*/React.createRef();

            toggleAll = function toggleAll(checked) {
              groupRef.current.toggleAll(checked);
            };

            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
              value: groupValue,
              ref: groupRef,
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Checkbox, {
              checked: false,
              name: "a",
              bindGroup: false
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "b"
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "c"
            })));
            items = wrapper.find('.rc-checkbox');
            items.at(0).simulate('click');
            expect(wrapper.props().value).toEqual([]);
            expect(onChange).not.toHaveBeenCalled();
            _context6.next = 11;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
              return _regeneratorRuntime.wrap(function _callee5$(_context5) {
                while (1) {
                  switch (_context5.prev = _context5.next) {
                    case 0:
                      toggleAll(true);

                    case 1:
                    case "end":
                      return _context5.stop();
                  }
                }
              }, _callee5);
            })));

          case 11:
            _context6.next = 13;
            return sleep(0);

          case 13:
            expect(onChange).toBeCalledWith(['b', 'c']);

          case 14:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should toggle all checkboxes when toggleAll method is called', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
    var onChange, groupValue, groupRef, toggleAll;
    return _regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            onChange = jest.fn();
            groupValue = [];
            groupRef = /*#__PURE__*/React.createRef();

            toggleAll = function toggleAll(options) {
              groupRef.current.toggleAll(options);
            };

            mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
              value: groupValue,
              ref: groupRef,
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Checkbox, {
              name: "a"
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "b"
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "c",
              disabled: true
            })));
            _context11.next = 7;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
              return _regeneratorRuntime.wrap(function _callee7$(_context7) {
                while (1) {
                  switch (_context7.prev = _context7.next) {
                    case 0:
                      toggleAll();

                    case 1:
                    case "end":
                      return _context7.stop();
                  }
                }
              }, _callee7);
            })));

          case 7:
            _context11.next = 9;
            return sleep(0);

          case 9:
            expect(onChange).toBeCalledWith(['a', 'b', 'c']);
            _context11.next = 12;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
              return _regeneratorRuntime.wrap(function _callee8$(_context8) {
                while (1) {
                  switch (_context8.prev = _context8.next) {
                    case 0:
                      toggleAll(false);

                    case 1:
                    case "end":
                      return _context8.stop();
                  }
                }
              }, _callee8);
            })));

          case 12:
            _context11.next = 14;
            return sleep(0);

          case 14:
            expect(onChange).toBeCalledWith([]);
            _context11.next = 17;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
              return _regeneratorRuntime.wrap(function _callee9$(_context9) {
                while (1) {
                  switch (_context9.prev = _context9.next) {
                    case 0:
                      toggleAll(true);

                    case 1:
                    case "end":
                      return _context9.stop();
                  }
                }
              }, _callee9);
            })));

          case 17:
            _context11.next = 19;
            return sleep(0);

          case 19:
            expect(onChange).toBeCalledWith(['a', 'b', 'c']);
            _context11.next = 22;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
              return _regeneratorRuntime.wrap(function _callee10$(_context10) {
                while (1) {
                  switch (_context10.prev = _context10.next) {
                    case 0:
                      toggleAll({
                        checked: true,
                        skipDisabled: true
                      });

                    case 1:
                    case "end":
                      return _context10.stop();
                  }
                }
              }, _callee10);
            })));

          case 22:
            _context11.next = 24;
            return sleep(0);

          case 24:
            expect(onChange).toBeCalledWith(['a', 'b', 'c']);

          case 25:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
});

==> rc-ui-lib-0.1.45.tgz: package/es/checkbox/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { act } from 'react-dom/test-utils';
import { Checkbox } from '..';
import mountTest from '../../../tests/shared/mountTest';
import { sleep } from '../../../tests/utils';
describe('Checkbox', function () {
  mountTest(Checkbox);
  mountTest(function () {
    return /*#__PURE__*/React.createElement(Checkbox, {
      checked: true,
      onChange: jest.fn()
    }, "Label");
  });
  it('renders correctly', function () {
    expect( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      onChange: jest.fn()
    }, "Label")).toMatchRenderedSnapshot();
  });
  it('render Custom icon correctly', function () {
    var activeIcon = 'https://img.yzcdn.cn/vant/user-active.png';
    var inactiveIcon = 'https://img.yzcdn.cn/vant/user-inactive.png';
    expect( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      iconRender: function iconRender(_ref) {
        var isActive = _ref.checked;
        return /*#__PURE__*/React.createElement("img", {
          alt: "",
          src: isActive ? activeIcon : inactiveIcon
        });
      }
    }, "\u81EA\u5B9A\u4E49\u56FE\u6807")).toMatchRenderedSnapshot();
  });
  it('should emit change event when checkbox icon is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onChange, wrapper, icon;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
              onChange: onChange
            }, "Label"));
            icon = wrapper.find('.rc-checkbox__icon');
            icon.simulate('click');
            expect(onChange).toBeCalledWith(true);
            _context.next = 7;
            return wrapper.setProps({
              checked: true
            });

          case 7:
            icon.simulate('click');
            expect(onChange).toBeCalledWith(false);

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should emit toggle event when checkbox is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var checkboxRef, toggle, wrapper;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            // const onToggle = jest.fn();
            checkboxRef = /*#__PURE__*/React.createRef();

            toggle = function toggle(checked) {
              checkboxRef.current.toggle(checked);
            };

            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
              ref: checkboxRef
            }, "Label"));
            _context3.next = 5;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
              return _regeneratorRuntime.wrap(function _callee2$(_context2) {
                while (1) {
                  switch (_context2.prev = _context2.next) {
                    case 0:
                      toggle();

                    case 1:
                    case "end":
                      return _context2.stop();
                  }
                }
              }, _callee2);
            })));

          case 5:
            wrapper.update();
            _context3.next = 8;
            return sleep();

          case 8:
            expect(wrapper.childAt(0).props().checked).toEqual(true); // expect(onToggle).toBeCalled();

          case 9:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should not emit "change" event when checkbox icon is disabled and clicked', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      disabled: true,
      onChange: onChange
    }, "Label"));
    wrapper.find('.rc-checkbox__icon').simulate('click');
    expect(onChange).not.toHaveBeenCalled();
  });
  it('should render "rc-checkbox--label-disabled" class when using label-disabled prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      labelDisabled: true,
      onChange: jest.fn()
    }, "Label"));
    expect(wrapper.find('.rc-checkbox--label-disabled')).toBeTruthy();
  });
  it('should emit "change" event when label is clicked', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      onChange: onChange
    }, "Label"));
    var icon = wrapper.find('.rc-checkbox__label');
    icon.simulate('click');
    expect(onChange).toBeCalledWith(false);
  });
  it('should not emit "change" event when label is disabled and clicked', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      labelDisabled: true,
      onChange: onChange
    }, "Label"));
    var icon = wrapper.find('.rc-checkbox__label');
    icon.simulate('click');
    expect(onChange).not.toHaveBeenCalled();
  });
  it('should adjust label position when using label-position prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: true,
      labelPosition: "left",
      onChange: jest.fn()
    }, "Label"));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should emit click event when checkbox icon is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var onClick, wrapper, icon;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            onClick = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox, {
              defaultChecked: true,
              labelPosition: "left",
              onClick: onClick
            }, "Label"));
            wrapper.simulate('click');
            expect(onClick).toHaveBeenCalledTimes(1);
            icon = wrapper.find('.rc-checkbox__icon');
            icon.simulate('click');
            expect(onClick).toHaveBeenCalledTimes(2);

          case 7:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
});
describe('Checkbox.Group', function () {
  mountTest(Checkbox.Group);
  it('renders correctly', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['1']
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "0"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "1",
      checked: true
    }, "\u9009\u9879\u4E8C"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "2"
    }, "\u9009\u9879\u4E09")));
    expect(wrapper).toMatchSnapshot();
  });
  it('render value correctly', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['0']
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "0"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "1"
    }, "\u9009\u9879\u4E8C"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "2"
    }, "\u9009\u9879\u4E09")));
    expect(wrapper).toMatchSnapshot();
  });
  it('should change icon size when using icon-size prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['1'],
      iconSize: "10rem"
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "0"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "1",
      iconSize: "5rem",
      checked: true
    }, "\u9009\u9879\u4E8C")));
    var icons = wrapper.find('.rc-checkbox__icon'); // expect(icons).toHaveLength(2);
    // console.log(icons.debug());
    // console.log(icons.at(0).getDOMNode());
    // console.log(icons.at(0).getDOMNode());

    expect(icons.at(0).getDOMNode().style.fontSize).toEqual('10rem');
    expect(icons.at(1).getDOMNode().style.fontSize).toEqual('5rem');
  });
  it('should limit change num when using max prop', function () {
    var onChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['a', 'b'],
      max: 2,
      onChange: onChange
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "a"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "b"
    }, "\u9009\u9879\u4E8C"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "c"
    }, "\u9009\u9879\u4E09")));
    var icons = wrapper.find('.rc-checkbox__icon');
    icons.at(2).simulate('click');
    expect(onChange).toHaveBeenCalledTimes(0);
    icons.at(0).simulate('click');
    expect(onChange).toHaveBeenCalledTimes(1);
    icons.at(1).simulate('click');
    expect(onChange).toHaveBeenCalledTimes(2);
  });
  it('should change checked color when using checked-color prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
      value: ['a', 'b'],
      checkedColor: "black"
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "a"
    }, "\u9009\u9879\u4E00"), /*#__PURE__*/React.createElement(Checkbox, {
      name: "b",
      checkedColor: "white"
    }, "\u9009\u9879\u4E8C")));
    var icons = wrapper.find('i.van-icon'); // console.log(icons.at(0).getDOMNode().style);
    // console.log(icons.at(1).getDOMNode().style);

    expect(icons).toHaveLength(2);
    expect(icons.at(0).getDOMNode().style.backgroundColor).toEqual('black');
    expect(icons.at(1).getDOMNode().style.backgroundColor).toEqual('white');
  });
  it('should ignore Checkbox if bind-group is false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onChange, groupValue, groupRef, toggleAll, wrapper, items;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            onChange = jest.fn();
            groupValue = [];
            groupRef = /*#__PURE__*/React.createRef();

            toggleAll = function toggleAll(checked) {
              groupRef.current.toggleAll(checked);
            };

            wrapper = mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
              value: groupValue,
              ref: groupRef,
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Checkbox, {
              checked: false,
              name: "a",
              bindGroup: false
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "b"
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "c"
            })));
            items = wrapper.find('.rc-checkbox');
            items.at(0).simulate('click');
            expect(wrapper.props().value).toEqual([]);
            expect(onChange).not.toHaveBeenCalled();
            _context6.next = 11;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
              return _regeneratorRuntime.wrap(function _callee5$(_context5) {
                while (1) {
                  switch (_context5.prev = _context5.next) {
                    case 0:
                      toggleAll(true);

                    case 1:
                    case "end":
                      return _context5.stop();
                  }
                }
              }, _callee5);
            })));

          case 11:
            _context6.next = 13;
            return sleep(0);

          case 13:
            expect(onChange).toBeCalledWith(['b', 'c']);

          case 14:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should toggle all checkboxes when toggleAll method is called', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
    var onChange, groupValue, groupRef, toggleAll;
    return _regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            onChange = jest.fn();
            groupValue = [];
            groupRef = /*#__PURE__*/React.createRef();

            toggleAll = function toggleAll(options) {
              groupRef.current.toggleAll(options);
            };

            mount( /*#__PURE__*/React.createElement(Checkbox.Group, {
              value: groupValue,
              ref: groupRef,
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Checkbox, {
              name: "a"
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "b"
            }), /*#__PURE__*/React.createElement(Checkbox, {
              name: "c",
              disabled: true
            })));
            _context11.next = 7;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
              return _regeneratorRuntime.wrap(function _callee7$(_context7) {
                while (1) {
                  switch (_context7.prev = _context7.next) {
                    case 0:
                      toggleAll();

                    case 1:
                    case "end":
                      return _context7.stop();
                  }
                }
              }, _callee7);
            })));

          case 7:
            _context11.next = 9;
            return sleep(0);

          case 9:
            expect(onChange).toBeCalledWith(['a', 'b', 'c']);
            _context11.next = 12;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
              return _regeneratorRuntime.wrap(function _callee8$(_context8) {
                while (1) {
                  switch (_context8.prev = _context8.next) {
                    case 0:
                      toggleAll(false);

                    case 1:
                    case "end":
                      return _context8.stop();
                  }
                }
              }, _callee8);
            })));

          case 12:
            _context11.next = 14;
            return sleep(0);

          case 14:
            expect(onChange).toBeCalledWith([]);
            _context11.next = 17;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
              return _regeneratorRuntime.wrap(function _callee9$(_context9) {
                while (1) {
                  switch (_context9.prev = _context9.next) {
                    case 0:
                      toggleAll(true);

                    case 1:
                    case "end":
                      return _context9.stop();
                  }
                }
              }, _callee9);
            })));

          case 17:
            _context11.next = 19;
            return sleep(0);

          case 19:
            expect(onChange).toBeCalledWith(['a', 'b', 'c']);
            _context11.next = 22;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
              return _regeneratorRuntime.wrap(function _callee10$(_context10) {
                while (1) {
                  switch (_context10.prev = _context10.next) {
                    case 0:
                      toggleAll({
                        checked: true,
                        skipDisabled: true
                      });

                    case 1:
                    case "end":
                      return _context10.stop();
                  }
                }
              }, _callee10);
            })));

          case 22:
            _context11.next = 24;
            return sleep(0);

          case 24:
            expect(onChange).toBeCalledWith(['a', 'b']);

          case 25:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
});
